// simulating AR2 models


clear *
set more off
 
// change working directory

set obs 2000
gen t = _n
tsset t
set seed 20160917


gen eps = rnormal(0,0.05)
gen ar2_real = 0 in 1/2
gen ar2_ur = 0 in 1/2
gen ar2_cc = 0 in 1/2

// two real roots
sca p1 = 0.9
sca p2 = -0.2
sca r1 = (-1 * -p1 + sqrt(p1^2 - 4*(-1)*p2))/(2 * (-1) * p2)
sca r2 = (-1 * -p1 - sqrt(p1^2 - 4*(-1)*p2))/(2 * (-1) * p2)
di _n "AR coeffs: " p1 " " p2
di _n "Roots via quadratic equation: " r1 " " r2
sca phi1 = (r1 + r2)
sca phi2 = (r1*r2)
di _n "Sum, product of roots: " phi1 " " phi2
sca soln1 = 1 - p1 * r1 - p2 * r1^2
sca soln2 = 1 - p1 * r2 - p2 * r2^2
di _n "Check solution: " soln1 " " soln2
di soln1
di soln2
loc phi1 = string(p1,"%5.1f")
loc phi2 = string(p2,"%5.1f")
loc root1 = string(r1,"%5.1f")
loc root2 =  string(r2,"%5.1f")
quietly replace ar2_real = p1 * L.ar2_real + p2 * L2.ar2_real + eps in 3/L
arima ar2_real, ar(1/2) nocons


tsline ar2_real, ti("Stationary: Two real roots", size(medsmall)) ///
	ylab(,angle(0)) yti("") xti("") name(ar2rr, replace) ///
	scheme(s1mono)
  

// one unit root
sca p1 = 1.8
sca p2 = -0.8
sca r1 = (-1 * -p1 + sqrt(p1^2 - 4*(-1)*p2))/(2 * (-1) * p2)
sca r2 = (-1 * -p1 - sqrt(p1^2 - 4*(-1)*p2))/(2 * (-1) * p2)
di _n "AR coeffs: " p1 " " p2
di _n "Roots via quadratic equation: " r1 " " r2
loc phi1 = string(p1,"%5.1f")
loc phi2 = string(p2,"%5.1f")
loc root1 = string(r1,"%5.1f")
loc root2 =  string(r2,"%5.1f")
quietly replace ar2_ur = p1 * L.ar2_ur + p2 * L2.ar2_ur + eps in 3/L

tsline ar2_ur, ti("Nonstationary: One unit root", size(medsmall)) ///
		ylab(,angle(0)) yti("") xti("") name(ar2ur, replace) ///
		scheme(s1mono) 


// two complex roots
sca p1 = 0.8
sca p2 = -0.5
sca rc1 = (-1 * -p1 + sqrt(p1^2 - 4*(-1)*p2))/(2 * (-1) * p2)
sca rc2 = (-1 * -p1 - sqrt(p1^2 - 4*(-1)*p2))/(2 * (-1) * p2)
di _n "AR coeffs: " p1 " " p2
di _n "Roots via quadratic equation: " rc1 " " rc2

mata:
p1 = 0.8
p2 = -0.5
radic = C( p1^2 - 4*(-1)*p2 )
rc1 = (-1 * -p1 + sqrt(radic))/(2 * (-1) * p2)
rc2 = (-1 * -p1 - sqrt(radic))/(2 * (-1) * p2)
rc1
rc2
st_local("a", strofreal(Re(rc1),"%5.3f"))
st_local("b", strofreal(Im(rc2),"%5.3f"))
st_local("modulus",strofreal(abs(rc1),"%5.3f"))
end

loc phi1 = string(p1,"%5.1f")
loc phi2 = string(p2,"%5.1f")
quietly replace ar2_cc = p1 * L.ar2_cc + p2 * L2.ar2_cc + eps in 3/L

arima ar2_cc, ar(1/2) nocons


tsline ar2_cc, ti("Stationary: Two complex roots", size(medsmall)) ///
		ylab(,angle(0)) ///
		yti("") xti("") name(ar2cr, replace)  scheme(s1mono) 


 
