// simulating AR(2) MA(2) and ARMA(2,2) models

clear all
capt log close
set scheme s1mono
set more off


// setup
set seed 123
local T = 5000
local obs = `T' + 500

// parameters
sca phi1 = 0.5
sca phi2 = 0.3
sca psi1 = -0.4
sca psi2 = 0.2

// generate errors
quietly set obs `obs'
quietly generate time = _n
quietly tsset time
quietly generate eps = 0.5*rnormal()

// generate AR(2)

quietly generate y = rnormal(0,1)  in 1/2
quietly replace  y = phi1*l.y + phi2*l2.y + eps in 3/l
quietly drop in 1/100
ac y,  lags(15) recast(bar) fcolor(none) ylab(,angle(0)) ytitle("Autocorrelations") xtitle("") ///
	note("") title("ACF of an AR(2) model", size(small)) name(ac1, replace)
pac y, lags(15)  recast(bar) fcolor(none) ylab(,angle(0)) ytitle("Partial autocorrelations") xtitle("") ///
	note("") title("PACF of an AR(2) model", size(small)) name(pac1, replace)
	
graph combine ac1 pac1, rows(2) imargin(tiny)
drop y eps time

// generate errors
quietly set obs `obs'
quietly generate time = _n
quietly tsset time
quietly generate eps = 0.5*rnormal()

// generate MA(2) 
 
quietly generate  y = rnormal(0,1)  in 1/2
quietly replace   y = psi1*l.eps + psi2*l2.eps + eps in 3/l
quietly drop in 1/100
ac y, lags(15) recast(bar) fcolor(none) ylab(,angle(0)) ytitle("Autocorrelations") xtitle("")  ///
	note("") title("ACF of a MA(2) model", size(small)) name(ac2, replace)
pac y, lags(15)  recast(bar) fcolor(none) ylab(,angle(0)) ytitle("Partial autocorrelations") xtitle("")  ///
	note("") title("PACF of a MA(2) model", size(small)) name(pac2, replace)

graph combine ac2 pac2, rows(2) imargin(tiny)

drop y eps time

// generate errors
quietly set obs `obs'
quietly generate time = _n
quietly tsset time
quietly generate eps = 0.5*rnormal()

// generate ARMA(2,2) 
 
quietly generate  y = rnormal(0,1)  in 1/2
quietly replace   y = phi1*l.y + phi2*l2.y + psi1*l.eps + psi2*l2.eps + eps in 3/l
quietly drop in 1/100
ac y,  lags(15) recast(bar) fcolor(none) ylab(,angle(0)) ytitle("Autocorrelations")  xtitle("") ///
	note("") title("ACF of a ARMA(2,2) model", size(small)) name(ac3, replace)
pac y,  lags(15) recast(bar) fcolor(none) ylab(,angle(0)) ytitle("Partial autocorrelations") xtitle("") ///
	note("") title("PACF of a ARMA(2,2) model", size(small)) name(pac3, replace)

graph combine ac3 pac3, rows(2) imargin(tiny)

graph combine ac1 ac2 ac3, rows(3) imargin(tiny)


graph combine pac1 pac2 pac3, rows(3) imargin(tiny)


