
clear *
set more off
set scheme s1mono

set seed 123
// acfs  
set obs 10001

generate t = _n
tsset t

generate y1 =.
generate y2 =.
generate e = rnormal(0,0.25 )
replace y1 = e in 1
replace y2 = e in 1
replace y1 = 0.0 + y1[_n-1] + e in 2/l
replace y2 = 0.0 + 0.5*y2[_n-1] + e in 2/l

su e y1

// simulate a fractional difference process
mata: 
mata clear

T     = 10000
INDEX = 0.5

acf = J(T+1,1,.)
y3  = J(T+1,1,.)


acf[1] = -1.0

for (k=0; k<T; k++) {

	acf[k+2]=acf[k+1]*(k-INDEX)/(k+1)
	
}


y3[1] = rnormal(1,1,0,1)
	
for (k=1; k<T; k++) {
	sum = 0.0
	for (j=1; j<=k; j++) {
			sum = sum + acf[j+1]*y3[k-j+1]
	}
	sum = sum + rnormal(1,1,0,1)
	y3[k+1] = sum
}
	
end

getmata y3


ac y2 in 500/1000, msymbol(i) fcolor(none) xtitle("") ytitle("") ///
		name(ac0,replace) recast(bar) note("") ylab(#4,angle(0)) ///
		title("Stationary process", size(medsmall))

// ac y1 in 500/1000, msymbol(i) fcolor(none) xtitle("") ytitle("") ///
//		name(ac1,replace) recast(bar) note("") ylab(#4,angle(0)) ///
//		title("Integrated process", size(medsmall))
		
ac y3 in 500/1000, msymbol(i) fcolor(none) xtitle("") ytitle("") ///
		name(ac2,replace) recast(bar) note("") ylab(#4,angle(0)) ///
		title("Fractionally integrated process", size(medsmall))
			
graph combine ac0 /* ac1 */  ac2, imargin(zero) rows(3)


// spectral density and power spectrum
arima y2 in 500/1000, ar(1)
psdensity y1d y1dfreq
line y1d y1dfreq, name(sd, replace)

//psdensity y1p y1pfreq, pspectrum 
//line y1p  y1pfreq, name(ps, replace)

use "fractionalcointegration.dta", clear
tsset datevec

generate trend = _n
regress Sea trend
predict double sea, res

regress Temp trend
predict double temp, res
		
ac sea, msymbol(i) fcolor(none) xtitle("") ytitle("") ///
		name(sea,replace) recast(bar) note("") ylab(#4,angle(0)) ///
		title("Mean sea level", size(medsmall))

ac temp, msymbol(i) fcolor(none) xtitle("") ytitle("") ///
		name(temp,replace) recast(bar) note("") ylab(#4,angle(0)) ///
		title("Global temperature", size(medsmall))

		
graph combine sea temp, imargin(zero) rows(2)


// Lo modified range statistic
// package lomodrs from http://fmwww.bc.edu/RePEc/bocode/l
use "fci", clear
lomodrs Sea, maxlag(0)	
lomodrs Temp, maxlag(0)

lomodrs Sea 
lomodrs Temp 

kpss Sea, qs 
kpss Temp, qs

// KPSS rejects trend stationarity
