clear *
set more off
set scheme s1mono

use "santiago", clear
tabstat v, by(winddir) stat(N mean sd min max)

// forecasting models
/* --------------------------- AR ------------------------- */

capture drop f_v sd_v upper lower
arima v if tin(,31jul2015), ar(1/7) nolog
estimates store ar
forecast create ar, replace
forecast estimates ar
forecast solve, prefix(f_) begin(td(1aug2015)) end(td(31aug2015)) ///
				 simulate(betas, reps(500) stat(s, pref(sd_)) )
generate f_ar = f_v
generate upper = f_v + 1.96*sd_v
generate lower = f_v - 1.96*sd_v
twoway (tsline v, lc(gray)) (tsline f_v, lp(dash) lc(black)) ///
	  (tsline upper, lc(black) lw(medthick)) ///
	  (tsline lower, lc(black) lw(medthick)) if tin(31jul2015,31aug2015), ///
	  title("AR(7) model forecast") legend(off) ylabel(, angle(0) format(%3.1f)) ///
	  tlabel(, format(%td_dmy)) xtitle("") scheme(s1mono)



/* --------------------------- ARMA ------------------------- */
arima v if tin(,31jul2015), arima(2,0,2) nolog
estimates store arma
forecast create arma, replace
forecast estimates arma
drop f_v sd_v upper lower
forecast solve, prefix(f_) begin(td(1aug2015)) end(td(31aug2015)) ///
				 simulate(betas, reps(500) stat(s, pref(sd_)) )
generate f_arma = f_v


/* --------------------------- ARMAX ------------------------- */
arima v NNE ENE ESE SSE SSW WSW WNW NNW if tin(,31jul2015), ar(1/7) nolog noconstant
estimates store armax
forecast create armax, replace
forecast estimates armax
drop f_v sd_v
forecast solve, prefix(f_) begin(td(1aug2015)) end(td(31aug2015)) ///
				 simulate(betas, reps(500) stat(s, pref(sd_)) )
generate f_armax = f_v



/* --------------------------- evaluation ------------------------- */
fcstats v f_ar f_arma if tin(1aug2015,31aug2015) 
 
dmariano v f_ar f_arma if tin(1aug2015,31aug2015), maxlag(7)
 
fcstats v f_ar f_armax if tin(31jul2015,31aug2015) 
