// unobserved component model of sea-level and temperature
// "The statistical relation of sea-level and temperature revisited"
// Grassi, S., Hillebrand, E. and Ventosa-Santaulària, D.
// Dynamics of Atmospheres and Oceans, 64 (2013) 1–9.

set more off
set scheme s1mono



use "fci", clear

// predict out to 2100
tsappend, add(91)

// univariate model for sea level
capture drop Seahat  SeaRMSE Seaup Seadn 
ucm Sea, model(rwdrift)
predict Seahat, xb dynamic(2009) rmse(SeaRMSE)

gen Seaup = Seahat + 1.96 * SeaRMSE
gen Seadn = Seahat - 1.96 * SeaRMSE

tw (rarea Seaup Seadn year if tin(2009,), fi(inten10)) ///
	(tsline Sea if tin(1900,2009), lc(black) ) ///
	(tsline Seahat if tin(2010,), lc(gray) lp(longdash)) , ///
	title("Forecast without interaction", size(medsmall)) ///
	ylab(,angle(0)) name(g1,replace) legend(off) ytitle("Sea level (cm)")

// Grassi model
use "fci", clear
// predict out to 2100
tsappend, add(91)
constraint 1 [muh]L.muh = 1
constraint 2 [muh]L.bh = 1
constraint 3 [mut]L.mut = 1
constraint 4 [mut]L.bt = 1
constraint 5 [bh]L.bh = 1
constraint 6 [bt]L.bt = 1
constraint 7 [Sea]muh = 1
constraint 8 [Temp]mut = 1
sspace (muh L.muh L.mut L.bh, state nocons noerror) ///
       (mut L.mut L.bt, state noconst noerror) ///
       (bh L.bh, state nocons) (bt L.bt, state noconst) ///
       (Sea muh, nocons) (Temp mut, nocons), const(1/8) difficult nolog vsquish 
	   
// state eqn
matlist e(A)
matlist e(C)
// measurement eqn
matlist e(D)


capture drop Seahat  SeaRMSE Seaup Seadn 
predict Seahat, xb equation(Sea) dynamic(2009) rmse(SeaRMSE)


gen Seaup = Seahat + 1.96 * SeaRMSE
gen Seadn = Seahat - 1.96 * SeaRMSE


tw (rarea Seaup Seadn year if tin(2009,), fi(inten10)) ///
	(tsline Sea if tin(1900,2009), lc(black) ) ///
	(tsline Seahat if tin(2010,), lc(gray) lp(longdash)) , ///
	title("Forecast with interaction", size(medsmall)) ///
	ylab(,angle(0)) name(g2, replace) legend(off) ytitle("Sea level (cm)")
 
//legend(rows(1) order(2 3 1)) ti("Ex ante forecast of Global Mean Annual Sea Level", size(medsmall)) ///

graph combine  g2 g1, ycom  

 
