// green risk

clear *
set more off
set scheme s1mono

use "djsidata", replace


// keep only the data for the period in which all indices are available
format date %td
tsset date
keep if tin(31jan2004,30jun2017)

// interpolate missing values for the na and eu indexes
ipolate na date, gen(tmp)
replace na=tmp
drop tmp

ipolate eu date, gen(tmp)
replace eu=tmp
drop tmp


// plots
twoway (tsline na),	title("North America") ///
		ytitle("Index") ylabel(,angle(0)) xtitle("") ///
		tlabel(, format(%tdCCYY)) ///
		scheme(s1mono)  name(na, replace)

twoway 	(tsline eu), title("Europe") ///
		ytitle("Index") ylabel(,angle(0)) xtitle("") ///
		tlabel(, format(%tdCCYY)) ///
		scheme(s1mono) name(eu, replace)

twoway 	(tsline ap), title("Asia Pacific") ///
		ytitle("Index") ylabel(,angle(0)) xtitle("") ///
		tlabel(, format(%tdCCYY)) ///
		scheme(s1mono) name(ap, replace)
		
twoway (tsline sp), title("S&P 500") ///
		ytitle("Index") ylabel(,angle(0)) xtitle("") ///
		tlabel(, format(%tdCCYY)) ///
		scheme(s1mono) name(sp, replace)

graph combine na eu ap sp, imargin(small) rows(2) cols(2)

	

// fix the weekend and non-trading day gaps 
generate t=_n
tsset t


// generate excess returns
generate rsp = 100*( (log(sp)-log(L.sp)) - rf )
generate rdj = 100*( (log(dj)-log(L.dj)) - rf )
generate rru = 100*( (log(ru)-log(L.ru)) - rf )
generate rwd = 100*( (log(world)-log(L.world)) - rf )
generate rna = 100*( (log(na)-log(L.na)) - rf )
generate reu = 100*( (log(eu)-log(L.eu)) - rf )
generate rap = 100*( (log(ap)-log(L.ap)) - rf )
generate r2 = rwd^2

save "djsi", replace

// plot of world excess return
twoway (line rwd date, lc(black)), ///
		title("",size(medsmall)) ///
		ytitle("Excess return") ylabel(,angle(0)) xtitle("") ///
		xlabel(, format(%tdCCYY)) ///
		scheme(s1mono) name(wd, replace)



twoway (line r2 date, lc(black)), ///
		title(" ", size(medsmall)) ///
		ytitle("Squared excess return") ylabel(,angle(0)) xtitle("") ///
		xlabel(, format(%tdCCYY)) ///
		scheme(s1mono) name(wd2, replace)

graph combine wd wd2, cols(1) imargin(0) scheme(s1mono)
		

	
clear
use "djsi"
quietly regress rwd  
estat archlm 
	
arch rwd, arch(1) garch(1) nolog vsquish
predict hwd, variance

twoway (line hwd date, lc(black)), ///		 
		ytitle("Conditional variance") ylabel(,angle(0)) xtitle("") ///
		xlabel(, format(%tdCCYY)) ///
		scheme(s1mono)  


	
// estimates
eststo clear
eststo: arch rwd, arch(1) garch(1)
 
eststo: arch rwd, arch(1) garch(1) dist(t)
nlcom (nu: exp( _b[lndfm2:_cons]) + 2) 
 
eststo: arch rwd, arch(1) garch(1) dist(ged)
 
esttab est*, nostar booktabs scalars(ll)


	
// TGARCH
arch rwd, arch(1) garch(1) tarch(1) nolog vsquish


// EGARCH
arch rwd, earch(1) egarch(1) nolog vsquish


	
// conditional variance gap

arch rsp, arch(1) garch(1)
predict hsp, var

arch rwd, arch(1) garch(1)
drop hwd
predict hwd, var

generate hgap  = hwd - hsp

 twoway (line hgap  date, lc(black)), yline(0) ///
		title(" ",size(medsmall)) ///
		ytitle("Conditional variance gap") ylabel(,angle(0)) xtitle("") ///
		xlabel(, format(%tdCCYY)) ///
		scheme(s1mono) name(ap, replace)
		
	


// find max and min conditional variances (using Nick Cox's extremes)
extremes hwd date, n(3) high
	
// predictions
predict hhigh, variance dynamic(1187) // 10/17/2008 
 

// estimated mean of conditional variance
generate hmean = _b[ARCH:_cons]/(1- _b[ARCH:L.arch]- _b[ARCH:L.garch])


twoway  (line hmean date) ///
		(line hhigh date in 1187/l, lwidth(medthick) lcolor(gray)) ///
		(line hwd date, lwidth(vthin) lp(dash) lcolor(black)) if date > td(01jan2008), ///
		name(hforecast,replace) tlabel(#6,angle(0) format(%td_CCYY)) ///
		legend(off) xtitle("") ytitle("Conditional variance") ///
		ylabel(,angle(0) ) scheme(s1mono)


rm djsi.dta
