clear
set more off


// ---------------------------------------------------------------------------
// Periodicity

use brisbanetemp, clear

// average price
gen temp = (max+min)/2

// set as time series
tsset datevec

// time series plot of last several years
twoway tsline temp if datevec > td(31dec1999),  ylab(,angle(0)) ///
	name(plot, replace) tlabel(, format(%tdCCYY)) xtitle("") ///
    scheme(s1mono) ytitle("Temperature (Celsius)")

	
/* The time series plots reveal strong seasonality in average temperature */

// unconditional distribution of temperature
hist temp, name(dist, replace) xtitle("Temperature (Celsius)") kdensity ///
	ylab(,angle(0)) frequency ytitle("Frequency (days)") scheme(s1mono) 



/* Seasonality in daily average temp results in unconditional temperature 
distribution being bimodal */

// ---------------------------------------------------------------------------
// Diurnality

// data on air pollution in Chile
// hourly data is collapsed into monthly means
// NO--THIS DATASET CONTAINS HOURLY DATA
use cerrillosm, clear

// THIS CODE DOES NOT REPRODUCE THE PRIOR VERSION OF THE FIGURE,
// WHICH WAS PRODUCED IN THE SINGLE SUBDIRECTORY
// plot the data
tsset datevec, delta(1 hour)
twoway tsline pm25, tlabel(#4, format(%tcCCYY)) xtitle("") legend(off) ///
	ylabel(,angle(0))  ytitle("PM2.5 Particles ({&mu}/m{sup:3})") scheme(s1mono)

gen hours = hh(datevec)+1

graph hbar pm25, over(hours) ytitle("Means of PM2.5") scheme(s1mono)

g month = month(dofc(datevec))
g winter= inrange(month,6,8)
g summer = inrange(month,1,2) | month==12
g season = winter + 2*summer
replace season=. if season==0


gr hbar pm25 if summer,  over(hours) yti("Mean of PM2.5") name(summer, replace) ti("Summer months") scheme(s1mono)
gr hbar pm25 if winter,  over(hours) yti("Mean of PM2.5") name(winter, replace) ti("Winter months") scheme(s1mono)
gr combine summer winter, rows(1) scheme(s1mono) xcom

// durations
 gen td = dofc(datevec)
 g yy = year(td)
 g mm = month(td)
 g dd = day(td)
 gen sixhours = hh(datevec)  // 0-23
 g sixhr = 6 * int(sixhours/6) + 5
 g double tstamp = mdyhms(mm,dd,yy,sixhr,59,0)
 format tstamp %tc
 
 preserve
 collapse pm25 co t hr dv vv, by(tstamp)
 tsset tstamp, delta(6 hours)
 tsspell pm25, pcond(pm25>25)
 save "pm25exceedance_6hr", replace
 restore
 
 collapse pm25 co t hr dv vv, by(td)
 tsset td, daily
 tsspell pm25, pcond(pm25>25)
 save "pm25exceedance_daily", replace

 
//keep if _end
 hist _seq if _seq>1 & _end==1, percent  xtitle("Durations (days)") discrete ///
 	ytitle("Percentage") ylab(#7,angle(0)) xlab(#10) scheme(s1mono)


// ---------------------------------------------------------------------------
// sunspot data
use "sunspots", clear

tsset datevec
twoway tsline sunspots, name(sunspots, replace) ///
	ytitle("Mean monthly sunspots") xtitle("") tlabel(, format(%tmCCYY)) ///
	scheme(s1mono) ylab(,angle(0))


// ---------------------------------------------------------------------------
// monthly data on Southern Oscillation Index
 use soi, clear

* reshape to long
 reshape long soi, i(year) j(month) string

 * gen monthly timestamp
 gen datevec = tm(1876m4)+_n-1
 format %tm datevec
 order datevec, first
 tsset datevec

* plot the Southern Oscillation Index
 twoway (tsline soi) if datevec >= tm(1980m1), title("") ///
	name(soi, replace) title("Southern oscillation index") xtitle("") ///
	ytitle(SOI) ///
	scheme(s1mono) tlabel(, format(%tmCCYY)) ylab(,angle(0))
	

// --------------------------------------------------------------------------- 
// Stern and Kaufman (2014) climate change data set

use "stern&kaufmann2014", clear

tsset datevec 
twoway (tsline hadcrut4) (tsline gissv3, lpattern(dash)), ylab(#6,angle(0)) yline(0) ///
 xtitle("") ytitle("Temperature anomaly") scheme(s1mono) legend(order(1 "Hadcrut4" 2 "Giss"))
	
 
 
// --------------------------------------------------------------------------- 
// CO2 plot
 

use logpercapitaco2, clear

tsset year

// choose the US
gen y = log(co2_australia)
gen dy = y-L.y


 
#delimit ;
twoway (tsline y, yaxis(1) lcolor(gray) ylab( ,angle(0) format(%3.2fc)) ) 
	   (tsline dy, yaxis(2)  lc(black) lp(dash) ylab( ,angle(0) format(%3.2fc)) ) 
		if year > 1900,  ytitle("Log CO{sub:2} emissions Australia") 
		ytitle("Change in log CO{sub:2} emissions Australia", axis(2))
		xtitle("") legend(off)
		name(aus, replace);		
		
#delimit cr



rm pm25exceedance_6hr.dta
rm pm25exceedance_daily.dta

