// Setting up the data used in 
// "How do Carbon Emissions Respond to Business-Cycle Shocks?"
// by Hashmat Khan Christopher R. Knittel Konstantinos Metaxoglou and Maya Papineau
// pdf saved as ../Papers/EDSGE_latest.pdf
clear *


// load the monthly carbon emissions
import excel "us_co2_emissions_by_source.xlsx", ///
		sheet("Monthly Data") cellrange(O13:O533) clear
ren O co2
	
// set up as time series
gen datevec = tm(1973m1)+_n-1
tsset datevec, monthly  

// need to seasonally adjust using Census X12
x11as co2 

//tsline co2*, ylab(,angle(0))

 
// aggregate to quarterly emissions
gen qdate = qofd(dofm(datevec))
format %tq qdate

collapse (sum) co2_as, by(qdate) 
drop in l
ren co2_as co2

// now save
save "quarterlyusco2.dta", replace


import excel "co2businesscycleshocks.xls", ///
	sheet("Macro Data") cellrange(B13:J286) clear


ren B CNP16OV			// population
ren C GDPC96			// real GDP
ren D HOANBS			// employment in non-farm business sector
ren E PCEND				// personal consumption expenditure
ren F DDURRG3Q086SBEA 	// durables price index
ren G DNDGRG3Q086SBEA   // nondurables price index
ren H DAAA 				// corporate AAA bond yields
ren I DBAA				// corporate BAA bond yields
ren J TFP				// utilization adjusted TFP

gen qdate = tq(1948q1)+_n-1

// merge the co2 data
merge 1:1 qdate using "quarterlyusco2.dta"
drop _merge

// add some notes
notes: This data set was compiled from the descriptions given in a working paper ///
by Khan, Knittel, Metaxoglou and Papineau (2015). All the macro data are listed ///
using their FRED identifiers.

notes: The data is not entirely the same as the original in the working paper as ///
there are some quality adjustment series used which are not in the public domain.

notes co2: Quarterly seasonally adjusted co2 emissions.
notes CNP16OV: Civilian Noninstitutional Population, Thousands of Persons, ///
Monthly, Not Seasonally Adjusted.
notes GDPC96: Real Gross Domestic Product, 3 Decimal, Billions of Chained 2009 Dollars, ///
Quarterly, Seasonally Adjusted Annual Rate.	
notes HOANBS: Nonfarm Business Sector,  Hours of All Persons, Index 2009=100, ///
Quarterly, Seasonally Adjusted.
notes PCEND: Personal Consumption Expenditures, Nondurable Goods, Billions of Dollars, ///
Quarterly, Seasonally Adjusted Annual Rate.
notes DDURRG3Q086SBEA: Personal consumption expenditures: Durable goods (chain-type price index), ///
Index 2009=100, Quarterly, Seasonally Adjusted.
notes DNDGRG3Q086SBEA: Personal consumption expenditures: Nondurable goods (chain-type price index), ///
Index 2009=100, Quarterly, Seasonally Adjusted.
notes TFP: Quarterly utilization-adjusted TFP.
notes DAAA: Corporate AAA bond yields.
notes DBAA: Corporate BAA bond yields.

// save .dta file
ren qdate datevec
order datevec
save "quarterlyusmacro.dta", replace


/* create a dataset with understandable names */
// give data some names
// co2 
replace co2 = co2/CNP16OV
label variable co2 "quarterly per capita co2 emissions"

// gdp
gen gdp = GDPC96
label variable gdp "real per capita gdp"

// labour productivity
gen lp = GDPC96/HOANBS
label variable lp "labour productivity"

// total factor productivity
gen tfp = TFP
label variable tfp "quarterly utilization adjusted total factor productivity"

// relative price of investment
gen p  = DNDGRG3Q086SBEA/DDURRG3Q086SBEA
label variable p "relative price of investment"

// credit spread
gen spread = DAAA-DBAA 
label variable spread "credit spread on corporate bond yields"


keep datevec co2 gdp lp tfp p spread
save "greensolow.dta", replace

/* ------------------------------------------------------------------------ */
rm quarterlyusco2.dta
rm "greensolow.dta"
rm "quarterlyusmacro.dta"
