// plots of load weighted price

clear *
set scheme s1mono
set more off

// load data
use "lwp", clear
gen llwp = log(lwp)
format date %td 
tsset date 
gen mn = month(date)
gen dd = dow(date)
save "llwp", replace

// plot the data 
tsline lwp, tlabel(, format(%td_CCYY)) xtitle("") ytitle("LWP") ///
			name(lwp, replace) ylab(,angle(0))

// gen llwp = log(lwp)
tsline llwp, tlabel(, format(%td_CCYY)) xtitle("") ytitle("Log LWP") ///
			name(llwp, replace) ylab(,angle(0))
			
//graph combine lwp llwp, imargin(tiny) cols(1)


* note the price increase during the 2007 drought (June/July)  
* note the price increase due to the carbon tax (July 2012-July2014)

// general concensus is that price as a mean reverting AR process
ac llwp, lags(21) recast(bar) fcolor(none) name(ac1, replace) ///
	xtitle("") note("") ytitle("") ylabel(,angle(0))  ///
	title("Autocorrelation function", size(small))
pac llwp, lags(21) recast(bar) fcolor(none) name(pac1, replace) ///
	xtitle("") note("") ytitle("") ylabel(,angle(0)) ///
	title("Partial autocorrelation function", size(small))

graph combine ac1 pac1, imargin(tiny) cols(1)


// gen mn = month(date)
// gen dd = dow(date)
tabstat lwp, stat(mean sd min max sk k) by(mn)


// ARMA modelling
// lag length
use "llwp", clear
varsoc llwp, maxlag(28)

// AR(14)
regress llwp L(1/14).llwp   

capt drop uhat
predict double uhat, resid
ac uhat, lags(28) recast(bar) fcolor(none) name(ac1, replace) ///
	xtitle("") note("") ytitle("") ylabel(,angle(0))  ///
	title("AR(14)", size(small))


// ARMA(2,2)
arima llwp, ar(1 2) ma(1 2) nolog vsquish 

// stability
estat aroots, nograph

capt drop uhat
predict double uhat, resid
ac uhat, lags(28) recast(bar) fcolor(none) name(ac2, replace) ///
	xtitle("") note("") ytitle("") ylabel(,angle(0))  ///
	title("ARMA(2,2)", size(small))


// ARMA-X(2,2)
xi: arima llwp i.dd, ar(1 2) ma(1 2) nolog vsquish 
	
capt drop uhat
predict double uhat, resid
ac uhat, lags(28) recast(bar) fcolor(none) name(ac3, replace) ///
xtitle("") note("") ytitle("") ylabel(,angle(0))  ///
title("ARMA-X(2,2)", size(small))
	

graph combine ac1 ac2 ac3, imargin(tiny) cols(1)

	
	
// Seasonal ARMA modelling

arima llwp, ar(1/2 7) ma(1 7) nolog vsquish 


capt drop uhat
predict double uhat, resid
ac uhat, lags(28) recast(bar) fcolor(none) name(ac1, replace) ///
	xtitle("") note("") ytitle("") ylabel(,angle(0))  ///
	title("Additive seasonal ARMA model", size(small))

arima llwp, arima(2,0,1) sarima(1,0,1,7) nolog vsquish 


capt drop uhat
predict double uhat, resid
ac uhat, lags(21) recast(bar) fcolor(none) name(ac2, replace) ///
	xtitle("") note("") ytitle("") ylabel(,angle(0))  ///
	title("Multiplicative seasonal ARMA model", size(small))

	
graph combine ac1 ac2, imargin(tiny) cols(1)
	

// auto
actest uhat, lags(1/28)



rm llwp.dta
