// file to reproduce some results from Borsky and Raschky (2015)
clear *
set more off



// load Borsky and Raschky (2015) data
use "spatialfish_small.dta", clear
  
//xtset, clear
  
// describe the data
describe
  
// line data up with Table 1 and results of estimations in Table 2
rename all_mean overall  
 
 
// set up spatial data
encode countrycode, gen(id)
spset id
spmatrix use WDIST using wdist.stswm, replace
 


// moran plot of behaviour
capture program drop moranplot
program moranplot
	syntax varname, spmatrix(string)

	tempname y Wy

	qui gen double `y' = `varlist'
	qui sum `y'
	local ybar = r(mean)
	local ysd = r(sd)
	qui replace `y' =(`y'-`ybar')/`ysd'
	spgenerate double `Wy' = `spmatrix'*`y'

	qui sum `Wy'
	local min = r(min)
	local max = r(max)
	local min = min(`min', -1)
	local max = max(`max', 1)
	local max = max(`max', abs(`min'))
	twoway scatter `Wy' `y', xscale(range(-`max' `max')) 		///
		|| lfit `Wy' `y', lc(gray) lp(longdash)					///
		yscale(range(-`max' `max'))				///
		title("Moran scatterplot of behavior", size(medsmall)) ///
		xtitle(`varlist')				///
		ytitle("Spatial lag of `varlist'") legend(off)	///
		xline(0, lstyle(refline)) yline(0, lstyle(refline)) scheme(s1mono)
end

moranplot behavior, spmatrix(WDIST)




// controls "gdp cost gov competition bio export eezcatch treaty"

use "spatialfish_small.dta", clear

// moran's test
rename distance cost
global controls "gdp cost gov competition bio export eezcatch treaty"
regress behavior $controls
encode countrycode, gen(id)
spset id
estat moran, errorlag(WDIST)
