// regression example using weekly data for Cerillos


clear *
set scheme s1mono
set more off


// load data
use "pm_daily", clear


// compute wind direction as circular statistic
capt drop winddir 
generate winddir = int((dv-1)/45) + 1

tabstat dv, by(winddir) stat(N min max)
label def wd 1 NNE 2 ENE 3 ESE 4 SSE 5 SSW 6 WSW 7 WNW 8 NNW
label val winddir wd

// NEED TO DROP NOCO TO GET ALL 8 WINDDIR IN THE EQN
// regress pm25 co temperature vv i.winddir, noco 
regress pm25 co temperature vv i.winddir 


test vv = -3

testparm i.winddir


quietly regress pm25 co temperature vv i.winddir 
predict double uhat, resid

tsline uhat, tlabel(,format(%tcCCYY)) xtitle("") ytitle("Residuals") ///
	ylab(,angle(0)) yline(0, lc(gray) lp(longdash))




// normality

hist uhat, fcolor(none) normal normopts(lc(gray) lw(medthick)) ylabel(, angle(0))


capt drop uhat
predict double uhat, resid
quietly summarize uhat, detail
scalar sk = r(skewness)^2/6
scalar kt = (r(kurtosis)-3)^2/24
scalar JB = r(N)*(sk+kt)
display as text "JB test statistic   =  " as res JB
display as text "Prob > chi2  =  "   as res chi2tail(2, JB)
mvtest normality uhat

quietly regress pm25 co temperature vv i.winddir 
// heteroskedasticity
estat hettest
estat imtest, white


// autocorrelation
estat bgodfrey, lag(1/6)
actest, lags(6) robust


// various estimates of variance
// THESE SHOULD NOT USE NOCO--OTHERWISE ONE OF THE WINDDIR IS IGNORED
generate month = month(days)
eststo clear
eststo: quietly regress pm25 co temperature vv i.winddir
 
eststo: quietly regress pm25 co temperature vv i.winddir, vce(robust)
 
eststo: quietly newey pm25 co temperature vv i.winddir, lag(7)
 
eststo: quietly regress pm25 co temperature vv i.winddir, vce(cluster month)
 
// NO REASON TO USE R-BAR-SQ AS ALL MODELS HAVE SAME K
esttab est* using "vcecomp.tex", style(tex) replace ///
cells(b(fmt(3)) se(par fmt(3))) legend label drop(_cons) sub("(mean) " "") ///
		nobase nonum  mti("OLS" "Robust" "HAC" "Cluster") ///
		stats(r2, fmt(%6.3f) labels("R-squared")) collabels(none)
