//  models for the sunspots data
 clear *
 set more off
 set scheme s1mono

 
use "annualsunspots.dta", clear
//plot the transition functions

twoway  (function y = (1+exp(-5*(x-0)))^(-1), range(-2 2) lc(black)) ///
		(function y = 1 - exp(-5*(x-0)^2), range(-2 2) lc(gray) lp(dash)), ///
		xtitle("y{sub:t-d}") legend(order(1 "LSTAR" 2 "ESTAR")) ///
		ylabel(, angle(0)) ytitle("") ///
		title("Smooth transition functions", size(medsmall))


 
 
// annual sunspots data


use "annualsunspots.dta", clear

tsset datevec 
// -------------------------------------------------------------------------- //
// step 1 - lag length of linear model  

generate y = 2*(sqrt(sunspots+1)-1)
varsoc y, maxlag(12)
* BIC indicates lag 9

// -------------------------------------------------------------------------- //
// step 2 - find the delay parameter 


use "annualsunspots.dta", clear
tsset datevec
generate y = 2*(sqrt(sunspots+1)-1)
forvalues d = 1/4 {
	capture drop st 
	capture drop st2 
	capture drop st3
	quietly generate st  = L`d'.y
	quietly generate st2 = st^2
	quietly generate st3 = st^3
	quietly regress y L(1/9)y c.L(1/9)y#c.st c.L(1/9)y#c.st2 c.L(1/9)y#c.st3
	quietly testparm c.L(1/9)y#c.st c.L(1/9)y#c.st2 c.L(1/9)y#c.st3
	display "Delay  "  `d'   "   p-value    " r(p)
}
* delay chosen to be 2 

// -------------------------------------------------------------------------- //
// test for STAR or ESTAR for d=2


capture drop st 
capture drop st2 
capture drop st3
quietly generate st  = L2.y
quietly generate st2 = st^2
quietly generate st3 = st^3
quietly regress y L(1/9)y c.L(1/9)y#c.st c.L(1/9)y#c.st2 c.L(1/9)y#c.st3
quietly testparm c.L(1/9)y#c.st3
display "F03 =   "   r(F)  "   p-value   " r(p)
quietly regress y L(1/9)y c.L(1/9)y#c.st c.L(1/9)y#c.st2  
quietly testparm c.L(1/9)y#c.st2
display "F02 =   "   r(F)  "   p-value   " r(p)
quietly regress y L(1/9)y c.L(1/9)y#c.st  
quietly testparm c.L(1/9)y#c.st
display "F01 =   "   r(F)  "   p-value   " r(p)
* strongest rejection is F01 - LSTAR selected

// -------------------------------------------------------------------------- //
// estimation stage 1
// take d = 2 gam = 4.7  c = 7.8 get starting values by OLS

quietly summarize L2.y
global ss = 1/r(sd)
// transition function
generate w = 1/( 1 + exp(-4.7*$ss*(L2.y - 7.8)))
// ols starting values
quietly regress y L.y L2.y L7.y  ///
w c.L1.y#c.w c.L2.y#c.w c.L3.y#c.w c.L7.y#c.w c.L8.y#c.w c.L9.y#c.w c.L11.y#c.w, noco
global a1  = _b[L1.y]
global a2 	= _b[L2.y]
global a7 	= _b[L7.y]
global b0  = _b[w]
global b1  = _b[cL1.y#c.w]
global b2  = _b[cL2.y#c.w]
global b3  = _b[cL3.y#c.w]
global b7  = _b[cL7.y#c.w]
global b8  = _b[cL8.y#c.w]
global b9  = _b[cL9.y#c.w]
global b11 = _b[cL11.y#c.w]
generate l1y  = L.y
generate l2y  = L2.y
generate l3y  = L3.y
generate l7y  = L7.y
generate l8y  = L8.y
generate l9y  = L9.y
generate l11y = L11.y
dropmiss, any obs force
nl (y = {a1}*l1y + {a2}*l2y + {a7}*l7y ///
	+ ({b0}+{b1}*l1y+{b2}*l2y+{b3}*l3y+{b7}*l7y+{b8}*l8y+{b9}*l9y+{b11}*l11y)* ///
	(1/( 1 + exp(-{gam} *$ss *(l2y - {c}))) ) ), ///
	variables(y) nolog vsquish ///
   	init(gam 4 c 8 a1 $a1 a2 $a2 a7 $a7 b0 $b0 b1 $b1 b2 $b2 b3 $b3 b7 $b7 b8 $b8 b9 $b9 b11 $b11)
estimates replay

test /a2+/b2=0
test /a7+/b7=0


predict fit 
loc c = /c

twoway (tsline y) (tsline fit, lp(dash) lc(gray)), ///
		yline(60.7, lc(black) lw(medthick) lp(dash)) ///
		ytitle("Actual and fitted annual sunspots") xtitle("")  name(sunspots, replace) ///
		scheme(s1mono) ylab(,angle(0)) legend(order(1 "Actual" 2 "Fitted")) yline(`c', lp(dash))



