clear *
set more off
set scheme s1mono


// load quarterly data
use "greensolow.dta", clear
tsset datevec, quarterly

replace gdp = log(gdp)

// generate growth rates
gen Dco2 =  log(co2)- log(L1.co2) 	
gen Dgdp =  D.gdp
gen Dp   = log(p)-log(L1.p) 	
gen Dlp  = log(lp) - log(L1.lp)	
gen Drc  = log(rc) - log(L1.rc)	

save "vars.dta",replace

// sureg and regress give same answers if run on the same sample
use "vars.dta", clear
regress  Dgdp L.Dco2 L.Dgdp if tin(1973q3,2016q1)
regress  Dco2 L.Dco2 L.Dgdp if tin(1973q3,2016q1) 

// sureg and regress give same answers
sureg ( Dgdp Dco2  = L.Dgdp L.Dco2 ) if tin(1973q3,2016q1), small dfk 

// as does var
var Dgdp Dco2 , lags(1) small dfk

// lag lengths
varsoc Dgdp Dco2, maxlag(8)  

// granger causality

quietly var Dgdp Dco2, lags(1) small dfk
vargranger

quietly var Dgdp Dco2, lags(1/2) small dfk
vargranger

// impulse responses
quietly var Dgdp Dco2, lags(1) small dfk
local endash = ustrunescape("\u2013")
irf create co2, step(8) set(co2) replace
irf graph oirf, irf(co2) impulse(Dgdp) response(Dco2) individual  scheme(s1mono) ///
	xtitle("Forecast horizon (quarters)") title("") legend(off) ///
	title("Impulse`endash'response:  GDP {&rarr} CO{sub:2}", size(medsmall)) iname(g1, replace) xlab(#5) subtitle("")
irf graph coirf, irf(co2) impulse(Dgdp) response(Dco2) individual  scheme(s1mono) ///
	xtitle("Forecast horizon (quarters)") title("") legend(off) ///
	title("Cumulative impulse`endash'response: GDP {&rarr} CO{sub:2}", size(medsmall)) iname(g2, replace) xlab(#5) subtitle("")

graph combine g11 g21, ycommon rows(1)


irf table oirf, irf(co2)  noci


irf table fevd, irf(co2)  noci  

 
