// code to generate and save weighting matrices
// first block = inverse distance
// second block = political distance

clear *



// load Borsky and Raschky (2015) data
use "spatialfish_small.dta", clear



// code for the custom matrices

keep countrycode
rename countrycode iso_d
sort iso_d
save dist_count_merge_isod.dta, replace

******		LAST SORT 		********
rename iso_d iso_o
sort iso_o
save dist_count_merge_isoo.dta, replace

************************************


*********ready to merge*************
merge iso_o using "dist_cepii.dta"
drop if _merge==2
drop _merge

sort iso_d
merge iso_d using dist_count_merge_isod.dta
tab _merge
drop if _merge==1

sort iso_o 
keep  iso_o iso_d dist
sort iso_o iso_d
reshape wide dist, i(iso_o) j(iso_d) string

// choose matrix type
foreach z of varlist dist* { 
 replace `z'=`z'/1000 
 replace `z'=1/exp(3*`z') 			/* exponential distance  */
// replace `z'=1/(`z');				/* inverse distance 		 
// replace `z'=1/(`z')^2;			/* squared inverse distance  

} 
 
// kill the diagonal elements 
mkmat  dist*, matrix(DIST) rownames(iso_o) 

local i=1
local nobs=_N								 
while `i' <=`nobs'{
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DIST[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}		

svmat DIST		
encode iso_o, gen(id)
xtset id
spset id				
spmatrix fromdata WDIST = DIST* , normalize(row)

spmatrix save WDIST using wdist.stswm, replace

spmat dta W DIST*, normalize(row) id(id)  replace
spmat graph W, title("Inverse exponential distance") name(dist, replace)



// code to construct the political distance matrix

clear *

// load small data set
use "spatialfish_small.dta", clear
sca drop _all

 

merge 1:m countrycode using treaty_all_final.dta
drop if _merge==2

keep  countrycode treatnr treatname treatplace treatyear
drop if  treatyear>2005
keep countrycode treatnr

gen treatdum=1 if treatnr!=0
egen countnumb=group(treatnr)
replace treatnr = countnumb
drop countnumb
reshape wide treatdum, i(countrycode) j(treatnr)

#delimit;
foreach z of varlist treatdum* {;
quietly replace `z'=0 if `z'==.;
};
#delimit cr

#delimit;
egen treatsum=rowtotal(treatdum*);
#delimit cr

sort countrycode							/* *** LAST SORT!!! *** */

local nobs= _N
mat TREAT=J(`nobs',`nobs',0)				

local i=1									/* **** Define weights for each element in matrix TREAT **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
			sca wm=0
#delimit;
foreach z of varlist treatdum*	{;
			sca wm=wm+(`z'[`i']*`z'[`j']);
			#delimit cr
			}
		if `i'==`j' {
		matrix TREAT[`i',`j']=0
				}
		if `i'~=`j' {
		matrix TREAT[`i',`j']=wm
			}
		sca drop wm
		local j=`j'+1 	
		}

local i=`i'+1
}									

****

mkmat treatsum, matrix(TREATSUM)
mat ii=J(`nobs',1,1)  
mat T=ii'
mat Z=TREATSUM*T

****

mat TREATREL=J(`nobs',`nobs',0)						
local i=1											/* **** Divide shared treaties by treatsum - generating relative amount of shared treaties for each country**** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix TREATREL[`i',`j']=0
				}
		if `i'~=`j' {
		matrix TREATREL[`i',`j']=TREAT[`i',`j']/443
			}
		local j=`j'+1 	
		}

local i=`i'+1
}									
**********************************************
**********************************************

keep countrycode

rename countrycode iso_d
sort iso_d
save dist_count_merge_isod.dta, replace

******		LAST SORT 		********
rename iso_d iso_o
sort iso_o
save dist_count_merge_isoo.dta, replace

************************************


*********ready to merge*************
merge iso_o using dist_cepii.dta
drop if _merge==2
drop _merge

sort iso_d
merge iso_d using dist_count_merge_isod.dta
tab _merge
drop if _merge==1

sort iso_o 
keep  iso_o iso_d dist
sort iso_o iso_d
reshape wide dist, i(iso_o) j(iso_d) string

preserve
#delimit
foreach z of varlist dist* {;
 replace `z'=`z'/1000;
 replace `z'=1/exp(3*`z');			
};
#delimit cr


#delimit;
mkmat  dist*, matrix(DIST) rownames(iso_o);
#delimit cr

local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DIST Matrix **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DIST[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}								
restore
****

mat TREATRELDIST=J(`nobs',`nobs',0)			/* **** Matrix 51*51 with 0 **** */
local i=1									/* **** loops to multiply elements of TREATREL and DISTI Matrix - generating weighted relative distance matrix for all countries **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix TREATRELDIST[`i',`j']=0
				}
		if `i'~=`j' {
		matrix TREATRELDIST[`i',`j']=TREATREL[`i',`j']*DIST[`i',`j']
			}
		local j=`j'+1 	
		}

local i=`i'+1
}					

****************
 
 

************************************
***   Defining PolDist Matrices  ***
************************************

svmat TREATRELDIST

encode iso_o, gen(id)
xtset id
spset id				
spmatrix fromdata WPOL = TREATRELDIST* , normalize(row)
spmatrix save WPOL using wpol.stswm, replace

spmat dta Wp TREATRELDIST*, normalize(row) id(id)  replace
spmat graph Wp, title("Political distance") name(wpol, replace)

spmat save Wp using wpol.spmat, replace



rm dist_count_merge_isod.dta
rm dist_count_merge_isoo.dta
