set more off
 

// load data and reshape to wide
use "allstations", clear

reshape wide pm co t hr vv dv station, i(datevec) j(id)
 

//choose station  
// 1 = cerillos
// 4 = elbosque

local id = 4 

// keep station wind speed  
keep datevec vv`id'
rename vv`id' v

gen month = month(dofc(datevec)) 

gen hours = hh(datevec)

// plot monthly average
gen tt = _n
gen monthave = .
quietly {
	forvalues i = 1/12 {
		scalar obs = `i'
		summ v if month == `i' 
		replace monthave = r(mean) in `i'  
	}
}
graph twoway (line monthave  tt) in 1/12, name(months, replace) xtitle(" ") ///
	ytitle("Average monthly wind speed") ylabel(, angle(0) format(%3.2f)) ///
	xla(1 "Jan " 3 "Mar" 6 "Jun" 9 "Sep" 12 "Dec") ///
	scheme(s1mono)

// plot hourly average
gen dailyave = .
quietly {
	forvalues i = 1/24 {
		scalar obs = `i'
		summ v if hour == `i' 
		replace dailyave = r(mean) in `i'  
	}
}

graph twoway (line dailyave  tt) in 1/24, name(hours, replace) xtitle(" ") ///
	ytitle("Average hourly wind speed") ylabel(, angle(0) format(%3.2f)) ///
	xla(1 " 1 a.m." 6 " 6 a.m." 12 " 12 p.m. " 18 "6 p.m." 23 "12 a.m.") ///
	scheme(s1mono)
	
graph combine months hours, rows(2) imargin(tiny) scheme(s1mono) ///
	title("Wind speed periodicity", size(medsmall)) 

